<?php
session_start();

// načte potřebné třídy
function nactiTridu($trida) {
    require("tridy/$trida.php");
}

spl_autoload_register("nactiTridu");

// připojí se k databázi
try {
    Db::connect('localhost', 'machr-registrace', 'root', '');
} catch (Exception $e) {
    die('Nepodařilo se připojit k databázi.');
}

$uzivatele = new Uzivatele();

// pro ověřování mailu
if (isset($_GET)) {
    if (isset($_GET['overeni'])) {
        if ($_GET['overeni'] == 'ano') {
            $zprava = 'Mail byl úspěšně ověřen.';
        } else {
            $zprava = 'Mail se nepodařilo ověřit. <a href="index.php?znovuzasli=ano">Znovu zaslat ověřovací mail.</a>';
        }
    } else if (isset($_GET['znovuzasli'])) {
        $uspech = $uzivatele->odesliOverujiciMail($_SESSION['mail'], $_SESSION['id_uzivatele']);
        if ($uspech) {
            $zprava = 'Ověřující mail byl znovu odeslán. Pokud Vám nedošel, zkontrolujte si složku se spamem.';
        }
    }
}

if ($_POST) {
    $reg = '#[a-zA-Z0-9._-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,4}#';
    if (isset($_POST['registrace'])) {
        // registrace uživatele
        if ($_POST['heslo'] != $_POST['heslo_znovu']) {
            //ověření hesla
            $zprava = 'Hesla nesouhlasí';
        } else if ($_POST['rok'] != date('Y')) {
            // ověření antispamu
            $zprava = 'Špatně jste vyplnil antispam';
        } else if(!preg_match($reg, $_POST['mail'])){
            // ověření správnosti mailu
            $zprava = 'Špatně jste vyplnil mail.';
        } else {
            // zjistí jeslti uživatel už neexistuje
            $existuje = $uzivatele->overeniExistence($_POST['mail']);
            if ($existuje) {
                $zprava = 'Uživatel s tímto mailem již existuje.';
            } else {
                // pokud neexistuje, vytvoří ho 
                $uzivatele->vytvorUzivatele($_POST['mail'], $_POST['heslo']);
                $zprava = 'Registrace proběhla úspěšně. Byl Vám zaslán ověřující mail. Pokud Vám nedošel, zkontrolujte si složku se spamem.';
            }
        }
    } else if (isset($_POST['prihlaseni'])) {
        // přihlášení uživatele
        $zprava = $uzivatele->prihlasUzivatele($_POST['mail'], $_POST['heslo']);
        if (empty($zprava)) {
            // pokud se přihlášení povede, přesměruje do adminu
            Header('Location: admin.php');
            exit();
        }
    } else if (isset($_POST['obnoveni'])) {
        // obnovení hesla
        $uspech = $uzivatele->obnovHeslo($_POST['mail']);
        if ($uspech) {
            $zprava = 'Na uvedený mail Vám bylo zasláno nové heslo.';
        } else {
            $zprava = 'Heslo se nepodařilo obnovit. Pravděpodobně jste zadal chybný mail.';
        }
    }
}
?>
<!DOCTYPE html>
<html>
    <head>
        <meta charset="UTF-8">
        <link rel="stylesheet" href="styl.css" type="text/css">
        <title>Machr na registraci a přihlašování</title>
    </head>
    <body>
        <div id="obsah">
            <h3>Registrace</h3>
            <div id="zprava">
                <div id="zprava-text">
                    <?php
                    if (isset($zprava)) {
                        echo($zprava);
                    } else {
                        echo('Heslo musí být dlouhé minimálně 7 znaků.');
                    }
                    ?>
                </div>
            </div>
            <form method="post" onsubmit="return kontrola();">
                Mail:<br>
                <input type="mail" name="mail" id="mail"><br>
                Heslo:<br>
                <input type="password" name="heslo" id="heslo"><br>
                Heslo znovu:<br>
                <input type="password" name="heslo_znovu" id="heslo-znovu"><br>
                Aktuální rok (antispam):<br>
                <input type="number" name="rok" id="rok"><br>
                <input type="submit" name="registrace" value="Registrovat"><br>
            </form>
            <p>
                Pokud už jste registrovaný, můžete se <a href="#" onclick="overlay('prihlaseni')">přihlásit</a>.
            </p>
        </div>

        <div class="overlay" id="prihlaseni">
            <div>
                <strong><a class="krizek" href='#' onclick="overlay('prihlaseni')">x</a></strong>
                <h3>Přihlášení</h3>
                <form method="post">
                    Mail:<br>
                    <input type="email" name="mail"><br>
                    Heslo:<br>
                    <input type="password" name="heslo"><br>
                    <input type="submit" name="prihlaseni" value="Přihlásit"><br>
                </form><br>
                <a href="#" onclick="overlay('zapomenute-heslo');
                        overlay('prihlaseni');">Zapomenuté heslo</a>
            </div>
        </div>

        <div class="overlay" id="zapomenute-heslo">
            <div>
                <strong><a class="krizek" href='#' onclick="overlay('zapomenute-heslo')">x</a></strong>
                <h3>Obnovení hesla</h3>
                <form method="post">
                    Mail:<br>
                    <input type="email" name="mail"><br>
                    <input type="submit" name="obnoveni" value="Zaslat nové heslo"><br>
                </form><br>
            </div>
        </div>
        <script type="text/javascript" src="js.js"></script>
    </body>
</html>
